from setuptools import setup

setup(name='probability_distros',
      version='0.1',
      description='Gaussian distributions',
      packages=['probability_distros'],
      author='Uzodinma Ikwuakor',
      author_email='uzo.ikwuakor@gmail.com',
      zip_safe=False)
